package examples.keyedfile;

/**
 * IBM Confidential                                                  
 * OCO Source Materials                                              
 * Satin Data Integration Toolkit
 * Prog License number                                               
 * (C) Copyright IBM Corp. 2002                                      
 * The source code for this program is not published or              
 * otherwise divested of its trade secrets, irrespective of          
 * what has been deposited with the US Copyright Office.             
 */

import com.ibm.OS4690.*;

/**
 * Modify records in a existing keyed file.
 * <p>
 * This adds or removes records in an existing keyed file.
 * @author Dan Streetman
 */
public class ModifyKeyedFile
{
	public static void main(String[] argv) throws Exception
	{
		if (argv.length != 4)
			usage();

		String filename = argv[0];
		String command = argv[1];
		String keyString = argv[2];
		String dataString = argv[3];

		KeyedFile keyedFile = new KeyedFile(filename, "rw", KeyedFile.SHARED_READ_ACCESS);
		int keyLength = keyedFile.getKeyLength();
		int recordSize = keyedFile.getRecordSize();

		if (keyLength != keyString.length()) {
			System.out.println("Key length must be " + keyLength);
			System.exit(1);
		}

		if ((recordSize-keyLength) != dataString.length()) {
			System.out.println("Data size must be " + (recordSize-keyLength));
			System.exit(1);
		}

		byte[] key = argv[2].getBytes();
		byte[] data = argv[3].getBytes();
		byte[] record = new byte[key.length + data.length];
		System.arraycopy(key, 0, record, 0, key.length);
		System.arraycopy(data, 0, record, key.length, data.length);

		if ("remove".equals(argv[1])) {
			keyedFile.delete(record);
			System.out.println("Removed record " + argv[2] + " " + argv[3]);
		} else if ("add".equals(argv[1])) {
			keyedFile.write(record, KeyedFile.NO_UNLOCK, KeyedFile.NO_HOLD);
			System.out.println("Added record " + argv[2] + " " + argv[3]);
		} else {
			usage();
		}

		keyedFile.closeFull();
	}

	public static void usage() throws Exception
	{
		System.out.println("Usage :\n\tjava examples.ModifyKeyedFile <file> add|remove <key> <data>");
		System.exit(1);
	}
}
