package examples.keyedfile;

/**
 * IBM Confidential                                                  
 * OCO Source Materials                                              
 * Satin Data Integration Toolkit
 * Prog License number                                               
 * (C) Copyright IBM Corp. 2002                                      
 * The source code for this program is not published or              
 * otherwise divested of its trade secrets, irrespective of          
 * what has been deposited with the US Copyright Office.             
 */

import com.ibm.mqe.*;

import examples.queuemanager.*;

/**
 * Perform a MQe request to a MqeKeyedFileService on a remote machine.
 * <p>
 * This asks a MqeKeyedFileService for a record from its keyed file.
 * MQe must have been correctly set up on both systems first, and started
 * on the remote (4690) system.  Additionally, the keyed file (on 4690)
 * must have been created, and must use the same key length as is specified
 * on the command line to this program.
 * @author Dan Streetman
 */
public class MqeKeyedFileClient
{
	public static void main(String[] argv) throws Exception
	{
		if (argv.length != 6) {
			System.out.println("Usage :\n\tjava examples.MqeKeyedFileClient <inifile> <remoteQM> <remoteQ> <key> <localreplyQM> <localreplyQ>");
			System.exit(1);
		}

		String iniFile = argv[0];
		String remoteQM = argv[1];
		String remoteQ = argv[2];
		String key = argv[3];
		String localQM = argv[4];
		String localQ = argv[5];

		MQeFields config = MQeQueueManagerUtils.loadConfigFile(iniFile);
		MQeQueueManagerUtils.processAlias(config);

		MQeQueueManager qM = new MQeQueueManager();
		qM.activate(config);

                MQeQueueManagerUtils.processListenerSections(config, qM);
		//MQeQueueManagerUtils.processListener(config, MQeQueueManagerUtils.processChannelManager(config));

		MQeMsgObject msg = new MQeMsgObject();
		msg.putArrayOfByte("Data", key.getBytes());
		msg.putAscii("RemoteQueueManager", localQM);
		msg.putAscii("RemoteQueue", localQ);

		qM.putMessage(remoteQM, remoteQ, msg, null, 0);

		MQeMsgObject reply = qM.waitForMessage(null, localQ, null, null, 0, 10000);

		String record = new String(reply.getArrayOfByte("Data"));

		System.out.println("Record for key " + key + " is " + record);

		System.exit(0);
	}
}
