package examples.soap;

import java.util.*;
import java.io.*;

import javax.xml.soap.*;

import com.ibm.retail.*;
import com.ibm.retail.di.net.protocol.*;
import com.ibm.retail.di.xml.messaging.soap.*;

/**
 * This Actor converts a SOAP message into a byte[] message.
 * <p>
 * This expects the input to be in the form produced by
 * {@link examples.soap.BytesToSoapConversionActor BytesToSoapConversionActor}.
 * Each line (delimited with a '\n' and/or '\r') is contained in
 * <line></line> tags, and each token (whitespace-delimited) is contained in
 * <token></token> tags.  The tokens and lines are re-converted to plain text.
 * @author Dan Streetman
 */
public class SoapToBytesConversionActor extends SoapStreamConversionActor
{
	static String COPYRIGHT = com.ibm.retail.di.Copyright.IBM_COPYRIGHT_SHORT;

	/**
	 * Convert the SOAP message to a byte[] object.
	 * @param requestHeaders The Request Headers.
	 * @param message The SOAP message.
	 * @param responseHeaders The response headers.
	 * @return A byte[] representing the SOAP message.
	 * @exception Exception If an error occurrs during conversion.
	 */
	protected byte[] convertSoapMessageToBytes(MessageHeaders requestHeaders, SOAPMessage message, MessageHeaders responseHeaders) throws Exception
	{
		StringBuffer sb = new StringBuffer();
		SOAPEnvelope envelope = message.getSOAPPart().getEnvelope();
		SOAPBody body = envelope.getBody();
		Iterator lines = body.getChildElements(envelope.createName("line"));
		while (lines.hasNext()) {
			SOAPElement lineElement = (SOAPElement)lines.next();
			Iterator tokens = lineElement.getChildElements(envelope.createName("token"));
			while (tokens.hasNext()) {
				SOAPElement tokenElement = (SOAPElement)tokens.next();
				sb.append(tokenElement.getValue() + " ");
			}
			sb.append("\n");
		}
		return sb.toString().getBytes();
	}

	/**
	 * This should not be called by this Actor, use BytesToSoapConversionActor instead.
	 * @exception RetailException This class does not support this method.
	 */
	protected SOAPMessage convertBytesToSoapMessage(MessageHeaders requestHeaders, byte[] data, MessageHeaders responseHeaders) throws Exception
	{
		throw new RetailException(getClass().getName() + " cannot convert bytes to a SOAP message.");
	}
}
