package examples.syncpointed;

/**
 * IBM Confidential                                                  
 * OCO Source Materials                                              
 * Satin Data Integration Toolkit
 * Prog License number                                               
 * (C) Copyright IBM Corp. 2002                                      
 * The source code for this program is not published or              
 * otherwise divested of its trade secrets, irrespective of          
 * what has been deposited with the US Copyright Office.             
 */

import javax.xml.soap.*;

import org.apache.commons.logging.*;

import com.ibm.retail.*;
import com.ibm.retail.di.xml.messaging.service.*;
import com.ibm.retail.di.net.protocol.*;
import com.ibm.retail.di.net.service.interactive.*;
import com.ibm.retail.di.service.util.*;

/**
 * Actor to generate faults (or not).
 * <p>
 * This is a no-operation Actor that either generates a fault (Exception) or
 * does nothing, depending on a context value.
 * @author Dan Streetman
 */
public class GenerateFaultActor extends AbstractActor
{
	/**
	 * Process a non-SOAP message.
	 * <p>
	 * This does nothing but set up the fault count.
	 * The generate-fault context boolean setting determines
	 * if a fault is generated or not.
	 * @param requestHeaders The request Headers.
	 * @param msg The non-SOAP message.
	 * @param responseHeaders The response Headers.
	 * @return A non-SOAP response.
	 * @exception Exception If a fault should be generated or an error occurs.
	 */
	public Object processNonSoapRequest(MessageHeaders requestHeaders, Object msg, MessageHeaders responseHeaders) throws Exception
	{
		logger.debug("Processing non-SOAP request.");

		boolean generateFault;

		try {
			generateFault = NamingTools.lookupBoolean(true, getContext(), getName(), GENERATE_FAULT_CONTEXT_KEY, true);
		} catch ( RetailException rE ) {
			logger.error("RetailException lookup up generate-fault property : " + rE.toString());
			generateFault = true;
		}

		logger.debug("Generate Fault is " + generateFault);
		if (generateFault)
			throw new Exception("Generated Fault.");

		return msg;
	}

	/**
	 * Process a SOAP message.
	 * <p>
	 * This does nothing but set up the fault count.
	 * The generate-fault context boolean setting determines
	 * if a fault is generated or not.
	 */
	protected SOAPMessage processSoapRequest(MessageHeaders requestHeaders, SOAPMessage msg, MessageHeaders responseHeaders) throws Exception
	{
		logger.debug("Processing SOAP request.");

		boolean generateFault;

		try {
			generateFault = NamingTools.lookupBoolean(true, getContext(), getName(), GENERATE_FAULT_CONTEXT_KEY, true);
		} catch ( RetailException rE ) {
			logger.error("RetailException lookup up generate-fault property : " + rE.toString());
			generateFault = true;
		}

		logger.debug("Generate Fault is " + generateFault);
		if (generateFault)
			throw new Exception("Generated Fault.");

		return msg;
	}

	/** required by inherited interface */
	public SOAPMessage onMessage(SOAPMessage msg) { throw new RuntimeException("Don't call"); }

	static Log logger = LogFactory.getLog(GenerateFaultActor.class);

	/* If this is set to true in the context, this generates an Exception; otherwise this does nothing. */
	public static final String GENERATE_FAULT_CONTEXT_KEY = "generate-fault";
}
