package examples.syncpointed;

/**
 * IBM Confidential                                                  
 * OCO Source Materials                                              
 * Satin Data Integration Toolkit
 * Prog License number                                               
 * (C) Copyright IBM Corp. 2002                                      
 * The source code for this program is not published or              
 * otherwise divested of its trade secrets, irrespective of          
 * what has been deposited with the US Copyright Office.             
 */

import java.io.*;

import com.ibm.mqe.*;
import com.ibm.mqe.mqemqmessage.*;

import examples.queuemanager.*;

import javax.xml.soap.*;

import com.ibm.retail.di.xml.messaging.soap.*;
import com.ibm.retail.di.net.protocol.*;

/**
 * Perform a MQe request to a MQeQueueManager queue, using a SOAPMessage as the data.
 * <p>
 * This simply creates a SOAPMessage containing the specified data
 * and sends it to the specified remote queue manager and queue
 * using the specified local queuemanager (which must be set up
 * with a Connection to send to the remote queue manager).
 * For byte[] messages, see examples.syncpointed.MqeClient.
 * @author Dan Streetman
 */
public class MqeSoapClient
{
	public static void main(String[] argv) throws Exception
	{
		if (argv.length != 5) {
			System.out.println("Usage :\n\tjava examples.MqeClient <inifile> <remoteQM> <remoteQ> <profileId> <data>");
			System.exit(1);
		}

		String iniFile = argv[0];
		String remoteQM = argv[1];
		String remoteQ = argv[2];
		String profileId = argv[3];
		String data = argv[4];
		SOAPMessage message = SoapUtil.createSoapMessage(MessageFactory.newInstance(), profileId, data);

		ByteArrayOutputStream baoS = new ByteArrayOutputStream();
		SoapUtil.saveSoapMessage(message, baoS);

		MQeFields config = MQeQueueManagerUtils.loadConfigFile(iniFile);
		MQeQueueManagerUtils.processAlias(config);

		MQeQueueManager qM = new MQeQueueManager();
		qM.activate(config);

		MQeMQMsgObject msg = new MQeMQMsgObject();
		msg.setData(baoS.toByteArray());

		qM.putMessage(remoteQM, remoteQ, msg, null, 0);

		System.exit(0);
	}
}
